// created by Josh Heyde
// last updated 25/01/09

#include "C_Rectangle.h"

// constructor
C_Rectangle::C_Rectangle(const int &l, const int &r, const int &t, const int &b)
: left(l), right(r), top(t), bottom(b)
{
}

// default constructor
C_Rectangle::C_Rectangle(): left(0), right(1), top(0), bottom(1)
{
}

// destructor
C_Rectangle::~C_Rectangle()
{
}

int C_Rectangle::getWidth() const
{
	return right - left;
}

int C_Rectangle::getHeight() const
{
	return bottom - top;
}

// if any of the sides are outside the other rectangle, then return
// false, otherwise, return true
bool C_Rectangle::allInternal(const C_Rectangle &destRect, const int &posX, const int &posY) const
{
	if(posX <= destRect.left)
		return false;

	if(posX + C_Rectangle::getWidth() >= destRect.right)
		return false;

	if(posY <= destRect.top)
		return false;

	if(posY + C_Rectangle::getHeight() >= destRect.bottom)
		return false;

	return true;
}

// if any of the sides are inside the other rectangle, then return
// false, otherwise, return true
bool C_Rectangle::allExternal(const C_Rectangle &destRect, const int &posX, const int &posY) const
{
	if(posX > destRect.right)
		return true;

	if(posX < destRect.left - C_Rectangle::getWidth())
		return true;

	if(posY > destRect.bottom)
		return true;

	if(posY < destRect.top - C_Rectangle::getHeight())
		return true;

	return false;
}

// note: for the use of this function, it is assumed you are calling
// it on the source rectangle and passing the destination as a
// parameter
void C_Rectangle::clip(const C_Rectangle &destRect)
{		
	if(left < destRect.left)
		left = destRect.left;

	if(right > destRect.right)
		right = destRect.right;

	if(top < destRect.top)
		top = destRect.top;

	if(bottom > destRect.bottom)
		bottom = destRect.bottom;
}

void C_Rectangle::operator = (const C_Rectangle &r)
{
	if(&r != this)
	{
		left = r.left;
		right = r.right;
		top = r.top;
		bottom = r.bottom;
	}
}
