// Note: adapted from a basic
// vector2 class from an assignment
#include "C_Vector.h"

// Constructors
C_Vector::C_Vector(void) : x(0),y(0) {}
C_Vector::C_Vector(float xin, float yin) : x(xin), y(yin) {}
C_Vector::C_Vector(const C_Vector &other) : x(other.x), y(other.y) {}

// Operators
const C_Vector & C_Vector::operator -=(const C_Vector &rhs)
{
	x -= rhs.x;
	y -= rhs.y;
	return *this;
}

const C_Vector & C_Vector::operator +=(const C_Vector &rhs)
{
	x += rhs.x;
	y += rhs.y;
	return *this;
}

const C_Vector & C_Vector::operator /=(const C_Vector &rhs)
{
	x /= rhs.x;
	y /= rhs.y;
	return *this;
}

const C_Vector & C_Vector::operator /=(const float &f)
{
	x /= f;
	y /= f;
	return *this;
}

const C_Vector & C_Vector::operator *=(const C_Vector &rhs)
{
	x *= rhs.x;
	y *= rhs.y;
	return *this;
}

const C_Vector & C_Vector::operator *=(const float &f)
{
	x *= f;
	y *= f;
	return *this;
}

const C_Vector & C_Vector::operator =(const C_Vector &rhs)
{
	if(&rhs != this)
	{
		x = rhs.x;
		y = rhs.y;
	}

	return *this;
}

const C_Vector C_Vector::operator -(const C_Vector &rhs) const
{
	C_Vector ret(*this);
	ret -= rhs;
	return ret;
}

const C_Vector C_Vector::operator +(const C_Vector &rhs) const
{
	C_Vector ret(*this);
	ret += rhs;
	return ret;
}

const C_Vector C_Vector::operator /(const C_Vector &rhs) const
{
	C_Vector ret(*this);
	ret /= rhs;
	return ret;
}

const C_Vector C_Vector::operator /(const float &fl) const
{
	C_Vector ret(*this);
	ret.x /= fl;
	ret.y /= fl;
	return ret;
}

const C_Vector C_Vector::operator *(const C_Vector &rhs) const
{
	C_Vector ret(*this);
	ret *= rhs;
	return ret;
}

const C_Vector C_Vector::operator *(const float &fl) const
{
	C_Vector ret(*this);
	ret.x *= fl;
	ret.y *= fl;
	return ret;
}

bool C_Vector::operator == (const C_Vector& c) const 
{
	if (c.x != x || c.y != y)
		return false;

	return true;
}

bool C_Vector::operator != (const C_Vector& c) const
{
	if (c.x == x || c.y == y)
		return false;

	return true;
}

// Functions

// Normalise this vector
void C_Vector::Normalise() 
{
	float len = Length();
	if(len == 0) 
		return;

	x /= len;
	y /= len;
}

// Calculates cosine angle between two vectors
float C_Vector::Dot(const C_Vector& other) const
{
	return x * other.x + y * other.y;
}

// Calculates the 2D cross product of 2 vectors resulting in a float which is 2 times the the area of the triangle
float C_Vector::Cross(const C_Vector& other) const
{
    return x * other.y - y * other.x;
}

C_Vector::~C_Vector(void){}


