#pragma once

#include <vector>

using std::string;

// forward declaration
class C_Sprite;

// allows the use of BYTE
typedef unsigned char BYTE;

class C_Visualisation
{
public:
	~C_Visualisation();
	bool initialise();
	void clearToColour(const BYTE &r, const BYTE &g, const BYTE &b, BYTE a = 255) const;
	bool createSprite(const std::string &filename, int &id, const int &numOfFrames, const int &frameWidth, const int &frameHeight, const bool &transparency = true);
	void drawSprite(const int &id, const int &posX, const int &posY, int &currentFrame) const;
	void displayText(const int &posX, const int &posY, string text, const BYTE &r, const BYTE &g, const BYTE &b, BYTE a = 255) const;
	const int getScreenWidth() const {return screenWidth;}
	void setScreenWidth(const int &newScreenWidth);
	const int getScreenHeight() const {return screenHeight;}
	void setScreenHeight(const int &newScreenHeight);

	// create singleton
	static void createVisual(const int &sw, const int &sh);
	// get singleton
	static C_Visualisation& getVisual() {return *vis;}
	// delete singleton
	static void deleteVisual();
private:
	// constructor
	C_Visualisation(const int &sw, const int &sh);

	int screenWidth;
	int screenHeight;
	BYTE *screen;
	std::vector <C_Sprite*> v_spriteVector;

	// singleton
	static C_Visualisation *vis;
}; 

#define VIS	C_Visualisation::getVisual()