// created by Josh Heyde
// last updated 25/01/09

#include "C_WorldEntity.h"
#include "C_Visualisation.h"
#include "C_Vector.h"
#include "C_Rectangle.h"
#include <assert.h>

C_WorldEntity::C_WorldEntity(const int &ID, const int &cF, const float &pX, const float &pY, const int &s)
: active(true), graphicID(ID), currentFrame(cF), speed(s)
{
	currentPosition = new C_Vector(pX, pY);
	nextPosition = new C_Vector(pX, pY);

	boundaries = new C_Rectangle(0, 16, 0, 16);
}

C_WorldEntity::~C_WorldEntity()
{
	delete currentPosition;
	delete nextPosition;
	delete boundaries;
}

// mutator functions
void C_WorldEntity::setActive(const bool &newActive)
{
	active = newActive;
}

void C_WorldEntity::setGraphicID(const int &newGraphicID)
{
	// error handling statements
	// asserting certain statements for this function
	assert(newGraphicID >= 0);

	graphicID = newGraphicID;
}

void C_WorldEntity::setSpeed(const int &newSpeed)
{
	// error handling statements
	// asserting certain statements for this function
	assert(newSpeed >= 0);
	
	speed = newSpeed;
}

void C_WorldEntity::setCurrentPosition(const int &newX, const int &newY)
{
	currentPosition->x = newX;
	currentPosition->y = newY;
}

void C_WorldEntity::setCurrentPosition(const C_Vector *newVector)
{
	// error handling statements
	// asserting certain statements for this function
	assert(newVector != NULL);
	
	if(currentPosition != newVector)
	{
		currentPosition->x = newVector->x;
		currentPosition->y = newVector->y;
	}
}

void C_WorldEntity::setNextPosition(const int &newX, const int &newY)
{
	nextPosition->x = newX;
	nextPosition->y = newY;
}

void C_WorldEntity::setNextPosition(const C_Vector *newVector)
{
	// error handling statements
	// asserting certain statements for this function
	assert(newVector != NULL);
	
	if(nextPosition != newVector)
	{
		nextPosition->x = newVector->x;
		nextPosition->y = newVector->y;
	}
}

void C_WorldEntity::setBoundaries(const int &newLeft, const int &newRight, const int &newTop, const int &newBottom)
{
	boundaries->left = newLeft;
	boundaries->right = newRight;
	boundaries->top = newTop;
	boundaries->bottom = newBottom;
}

void C_WorldEntity::setBoundaries(const C_Rectangle *newRect)
{
	// error handling statements
	// asserting certain statements for this function
	assert(newRect != NULL);
	
	if(!(boundaries == newRect))
	{
		boundaries->left = newRect->left;
		boundaries->right = newRect->right;
		boundaries->top = newRect->top;
		boundaries->bottom = newRect->bottom;
	}
}

// other member functions

void C_WorldEntity::update()
{
	*currentPosition = *nextPosition;
}