// created by Josh Heyde
// last updated 25/01/09

#pragma once

// forward declarations
class C_Vector;
class C_Rectangle;

#include <vector>

class C_WorldEntity
{
public:
	virtual ~C_WorldEntity();

	// accessor and mutator functions
	const bool getActive() const {return active;}
	virtual void setActive(const bool &newActive);
	const int getGraphicID() const {return graphicID;}
	void setGraphicID(const int &newGraphicID);
	const int getSpeed() const {return speed;}
	void setSpeed(const int &newSpeed);
	const C_Vector* getCurrentPosition() const {return currentPosition;}
	void setCurrentPosition(const int &newX, const int &newY);
	void setCurrentPosition(const C_Vector *newVector);
	const C_Vector* getNextPosition() const {return nextPosition;}
	void setNextPosition(const int &newX, const int &newY);
	void setNextPosition(const C_Vector *newVector);
	const C_Rectangle* getBoundaries() const {return boundaries;}
	void setBoundaries(const int &newLeft, const int &newRight, const int &newTop, const int &newBottom);
	void setBoundaries(const C_Rectangle *newRect);

	// pure virtual functions
	virtual const C_Vector* getDirection() const =0;
	virtual void determineDirection(std::vector <C_WorldEntity*> v_entityVector) =0;

	virtual int numberOfNearbyFlockers(std::vector <C_WorldEntity*> v_entityVector, const int &range) const {return 0;}
	virtual void toggleActive() {}

	// other member functions
	virtual void update();
	virtual void render(const float &currentTime) =0;

protected:
	// the constructor is protected to prevent any
	// instantiation of this class, but still allows
	// child classes to use it
	C_WorldEntity(const int &ID, const int &cF, const float &pX, const float &pY, const int &s);

	// data members
	bool active;
	int graphicID;
	int currentFrame;
	int speed;
	C_Vector* currentPosition;
	C_Vector* nextPosition;
	C_Rectangle* boundaries;
};